Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UWireError

#[non_exhaustive]
pub enum UWireError { BufferTooSmall { expected: usize, actual: usize, }, InvalidPayload(String), MissingEncoding, MissingPayload, UnsupportedEncoding { expected: Box<PayloadEncoding>, actual: Box<PayloadEncoding>, }, SerializationError(String), }
Error type used by serialization-neutral payload helpers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BufferTooSmall

A caller-provided output buffer is too small for the serialized payload.

Fields

expected: usize

Required output size in bytes.

actual: usize

Provided output size in bytes.



InvalidPayload(String)

Payload bytes are malformed for the selected decoder.



MissingEncoding

A typed decode was requested, but the frame has no payload encoding.



MissingPayload

A typed decode was requested, but the frame has no payload bytes.



UnsupportedEncoding

The frame’s encoding is not compatible with the selected payload codec.

Fields

expected: Box<PayloadEncoding>

Encoding declared by the requested codec.

actual: Box<PayloadEncoding>

Encoding carried by the frame being decoded.



SerializationError(String)

Serializer or deserializer implementation failed.

Implementations

Source

impl UWireError

pub fn buffer_too_small(expected: usize, actual: usize) -> Self

Creates a UWireError::BufferTooSmall value.

pub fn invalid_payload(message: impl Into<String>) -> Self

Creates a UWireError::InvalidPayload value.

pub fn invalid_payload_length(expected: usize, actual: usize) -> Self

Creates a stable payload length error.

pub fn serialization_error(message: impl Into<String>) -> Self