#[non_exhaustive]pub enum UWireError {
BufferTooSmall {
expected: usize,
actual: usize,
},
InvalidPayload(String),
MissingEncoding,
MissingPayload,
UnsupportedEncoding {
expected: Box<PayloadEncoding>,
actual: Box<PayloadEncoding>,
},
SerializationError(String),
}Expand description
Error type used by serialization-neutral payload helpers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooSmall
A caller-provided output buffer is too small for the serialized payload.
InvalidPayload(String)
Payload bytes are malformed for the selected decoder.
MissingEncoding
A typed decode was requested, but the frame has no payload encoding.
MissingPayload
A typed decode was requested, but the frame has no payload bytes.
UnsupportedEncoding
The frame’s encoding is not compatible with the selected payload codec.
Fields

expected: Box<PayloadEncoding>Encoding declared by the requested codec.

actual: Box<PayloadEncoding>Encoding carried by the frame being decoded.
SerializationError(String)
Serializer or deserializer implementation failed.
Implementations
Sourceimpl UWireError
impl UWireError
Sourcepub fn buffer_too_small(expected: usize, actual: usize) -> Self
pub fn buffer_too_small(expected: usize, actual: usize) -> Self
Creates a UWireError::BufferTooSmall value.
Sourcepub fn invalid_payload(message: impl Into<String>) -> Self
pub fn invalid_payload(message: impl Into<String>) -> Self
Creates a UWireError::InvalidPayload value.
Sourcepub fn invalid_payload_length(expected: usize, actual: usize) -> Self
pub fn invalid_payload_length(expected: usize, actual: usize) -> Self
Creates a stable payload length error.
Sourcepub fn serialization_error(message: impl Into<String>) -> Self
pub fn serialization_error(message: impl Into<String>) -> Self
Creates a UWireError::SerializationError value.